==> react-8.0.1.tgz: package/es/Spinner/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { isNumber, round } from 'lodash';
/**
 * @category communication
 * @component loader-spinner
 * @variations collab-ui-react
 */

var Spinner = function Spinner(props) {
  var className = props.className,
      color = props.color,
      percentage = props.percentage,
      showPercentage = props.showPercentage,
      size = props.size,
      otherHTMLProps = _objectWithoutProperties(props, ["className", "color", "percentage", "showPercentage", "size"]);

  if (isNumber(percentage)) {
    if (size !== 36 && showPercentage) {
      /* eslint-disable no-console */
      console.warn('Percentage will not be shown for sizes smaller than 36');
      /* eslint-enable no-console */
    }

    return React.createElement("div", _extends({
      className: "cui-spinner-progress" + ("" + (size && " cui-spinner-progress--" + size || '')) + ("" + (color && " cui-spinner-progress--" + color || '')) + ("" + (className && " " + className || '')) + (" cui-spinner-progress__percentage-" + round(percentage))
    }, otherHTMLProps), React.createElement("div", {
      className: "cui-spinner-progress__circle"
    }, React.createElement("div", {
      className: "cui-spinner-progress__mask cui-spinner-progress__full"
    }, React.createElement("div", {
      className: "cui-spinner-progress__fill"
    })), React.createElement("div", {
      className: "cui-spinner-progress__mask cui-spinner-progress__half"
    }, React.createElement("div", {
      className: "cui-spinner-progress__fill"
    }), React.createElement("div", {
      className: "cui-spinner-progress__fill cui-spinner-progress__fix"
    })), React.createElement("div", {
      className: "cui-spinner-progress__inset-circle"
    }, size === 36 && showPercentage && React.createElement("div", {
      className: "cui-spinner-progress__percentage"
    }, round(percentage)))));
  } else {
    return React.createElement("i", _extends({
      className: "cui-spinner" + ("" + (size && " cui-spinner--" + size || '')) + ("" + (color && " cui-spinner--" + color || '')) + ("" + (className && " " + className || ''))
    }, otherHTMLProps));
  }
};

Spinner.propTypes = {
  /**
   * css class names
   */
  className: PropTypes.string,

  /**
   * color
   */
  color: PropTypes.string,

  /**
   * percentage value to show on progress
   */
  percentage: PropTypes.number,

  /**
   * show the number value for progress
   */
  showPercentage: PropTypes.bool,

  /**
   * size
   */
  size: PropTypes.oneOf([16, 20, 28, 36])
};
Spinner.defaultProps = {
  className: '',
  color: 'black',
  percentage: null,
  showPercentage: false,
  size: 36
};
Spinner.displayName = 'Spinner';
export default Spinner;
/**
* @name Spinner
* @description Different states of spinners.
*
* @category communication
* @component loader-spinner
* @section states
*
* @js

import {Spinner} from '@collab-ui/react';

export default function Default() {
  return (
    <div>

      <div className="docs-example docs-example--spacing">
        <h3>Size Prop</h3>
        <h3><code className="small">size=(16)</code></h3>
        <Spinner size={16}/>
        <h3><code className="small">size=(20)</code></h3>
        <Spinner size={20}/>
        <h3><code className="small">size=(28)</code></h3>
        <Spinner size={28}/>
        <h3><code className="small">Default size=(36)</code></h3>
        <Spinner />
      </div>

      <div className="docs-example docs-example--spacing">
        <h3>Color Prop</h3>
        <h3><code className="small">color:blue</code></h3>
        <Spinner color='blue'/>
      </div>

      <div className="docs-example docs-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner</code></h3>
        <Spinner />
      </div>

      <div className="docs-example docs-example--spacing">
        <h3>Percentage Prop</h3>
        <h3><code className="small">percentage:65</code></h3>
        <Spinner percentage={65}/>
      </div>
      
    </div>
  );
}

**/

==> react-8.3.0.tgz: package/es/Spinner/index.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { isNumber, round } from 'lodash';
/**
 * @category communication
 * @component loader-spinner
 * @variations collab-ui-react
 */

var Spinner = function Spinner(props) {
  var className = props.className,
      color = props.color,
      percentage = props.percentage,
      showPercentage = props.showPercentage,
      size = props.size,
      otherHTMLProps = _objectWithoutPropertiesLoose(props, ["className", "color", "percentage", "showPercentage", "size"]);

  if (isNumber(percentage)) {
    if (size !== 36 && showPercentage) {
      /* eslint-disable no-console */
      console.warn('[@collab-ui/react] Spinner: Percentage will not be shown for sizes smaller than 36');
      /* eslint-enable no-console */
    }

    return React.createElement("div", _extends({
      className: "cui-spinner-progress" + ("" + (size && " cui-spinner-progress--" + size || '')) + ("" + (color && " cui-spinner-progress--" + color || '')) + ("" + (className && " " + className || '')) + (" cui-spinner-progress__percentage-" + round(percentage))
    }, otherHTMLProps), React.createElement("div", {
      className: "cui-spinner-progress__circle"
    }, React.createElement("div", {
      className: "cui-spinner-progress__mask cui-spinner-progress__full"
    }, React.createElement("div", {
      className: "cui-spinner-progress__fill"
    })), React.createElement("div", {
      className: "cui-spinner-progress__mask cui-spinner-progress__half"
    }, React.createElement("div", {
      className: "cui-spinner-progress__fill"
    }), React.createElement("div", {
      className: "cui-spinner-progress__fill cui-spinner-progress__fix"
    })), React.createElement("div", {
      className: "cui-spinner-progress__inset-circle"
    }, size === 36 && showPercentage && React.createElement("div", {
      className: "cui-spinner-progress__percentage"
    }, round(percentage)))));
  } else {
    return React.createElement("i", _extends({
      className: "cui-spinner" + ("" + (size && " cui-spinner--" + size || '')) + ("" + (color && " cui-spinner--" + color || '')) + ("" + (className && " " + className || ''))
    }, otherHTMLProps));
  }
};

Spinner.propTypes = {
  /**
   * css class names
   */
  className: PropTypes.string,

  /**
   * color
   */
  color: PropTypes.string,

  /**
   * percentage value to show on progress
   */
  percentage: PropTypes.number,

  /**
   * show the number value for progress
   */
  showPercentage: PropTypes.bool,

  /**
   * size
   */
  size: PropTypes.oneOf([16, 20, 28, 36])
};
Spinner.defaultProps = {
  className: '',
  color: 'black',
  percentage: null,
  showPercentage: false,
  size: 36
};
Spinner.displayName = 'Spinner';
export default Spinner;
/**
* @name Spinner
* @description Different states of spinners.
*
* @category communication
* @component loader-spinner
* @section states
*
* @js

import {Spinner} from '@collab-ui/react';

export default function Default() {
  return (
    <div>

      <div className="docs-example docs-example--spacing">
        <h3>Size Prop</h3>
        <h3><code className="small">size=(16)</code></h3>
        <Spinner size={16}/>
        <h3><code className="small">size=(20)</code></h3>
        <Spinner size={20}/>
        <h3><code className="small">size=(28)</code></h3>
        <Spinner size={28}/>
        <h3><code className="small">Default size=(36)</code></h3>
        <Spinner />
      </div>

      <div className="docs-example docs-example--spacing">
        <h3>Color Prop</h3>
        <h3><code className="small">color:blue</code></h3>
        <Spinner color='blue'/>
      </div>

      <div className="docs-example docs-example--spacing cui--dark docs-example--dark">
        <h3>Dark <code className="small">Spinner</code></h3>
        <Spinner />
      </div>

      <div className="docs-example docs-example--spacing">
        <h3>Percentage Prop</h3>
        <h3><code className="small">percentage:65</code></h3>
        <Spinner percentage={65}/>
      </div>

    </div>
  );
}

**/
